@@ -29,8 +29,9 @@
 #include <config.h>
 #endif
 
-#include <gtk/gtk.h>
+#include <glib/gerror.h>
 #include <glib.h>
+#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
 #include <libintl.h>
@@ -53,6 +54,7 @@
 #include <hildon-widgets/gtk-infoprint.h>
 #include <hildon-status-bar-lib/hildon-status-bar-item.h>
 #include <hildon-widgets/hildon-input-mode-hint.h>
+#include <hildon-widgets/hildon-number-editor.h>
 
 #define DBUS_API_SUBJECT_TO_CHANGE
 #include <dbus/dbus.h>
@@ -94,7 +96,7 @@
 typedef struct
 {
     HildonStatusBarItem *item;
-    /* Pixbufs for the loadedl icons */
+    /* Pixbufs for the loaded icons */
     GdkPixbuf *pixbuf_frame;
     GdkPixbuf *pixbuf_cpu;
     GdkPixbuf *pixbuf_mem;
@@ -127,6 +129,7 @@ typedef struct
 
 
 static gint lastU, lastN, lastIO, lastI;
+gint deltaU, deltaN, deltaIO, deltaI;
 static gint sshotn = 0;
 static PluginInfo *info = NULL;
 static gboolean im_inactive = FALSE;
@@ -332,8 +335,10 @@ make_screenshot(void)
     ret = gdk_pixbuf_save (pixbuf, sshotname, "png", &error, NULL);
     if (!ret)
     {
+        g_error_free (error);
         snprintf(sshotname, MAX_SSHOT_NAME_LEN-1, "/media/mmc1/%s%02d.png", sshotfilename, sshotn);
         ret = gdk_pixbuf_save (pixbuf, sshotname, "png", &error, NULL);
+        g_error_free (error);
     }
     
    
@@ -404,13 +409,13 @@ activate_settings_item(GtkMenuItem *item, gpointer data)
                             TRUE,
                             TRUE,
                             5);
-        sb_seconds = gtk_spin_button_new_with_range ( 0, 9999999, 1);	
+        sb_seconds = hildon_number_editor_new  (1, 60);	
         gtk_box_pack_start (GTK_BOX(hboxtop),
                             sb_seconds,
                             TRUE,
                             TRUE,
                             0);
-        gtk_spin_button_set_value (GTK_SPIN_BUTTON(sb_seconds), screenshot_delay);
+        hildon_number_editor_set_value (HILDON_NUMBER_EDITOR(sb_seconds), screenshot_delay);
 
         /* Screenshot name */
         hboxbottom = gtk_hbox_new (FALSE, 5);
@@ -445,7 +450,7 @@ activate_settings_item(GtkMenuItem *item, gpointer data)
                /* Save new delay and screenshot name */
                if (sshotfilename) g_free(sshotfilename);
                sshotfilename = g_strdup(gtk_entry_get_text(GTK_ENTRY(entry_filename)));
-               screenshot_delay = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(sb_seconds));
+               screenshot_delay = hildon_number_editor_get_value (HILDON_NUMBER_EDITOR(sb_seconds));
                gtk_widget_destroy(dialog);
                break;
         default:
@@ -581,54 +586,52 @@ blit_cpu_bars (const guchar level)
 
 
 static guchar
-check_cpu ()
+check_cpu (void)
 {
-    #define MAX_DIGITS_CHARS 32
-    FILE *fin;
-    gint curU, curN, curIO, curI;
-    int load, idle;
-    char digits[MAX_DIGITS_CHARS];
-    char *position;
+	gint curU, curN, curIO, curI;
+	int load, idle;
+	GError *error = NULL;
+	gchar *contents;
+	gsize lenght;
+	gchar **splits;
 
-    fin = fopen(CPUFILE, "r");
-    if (fin == NULL)
-    {
-        g_error("Can't open the "CPUFILE"\n");
-        return TRUE;
-    }
-    fgets(read_buffer, MAX_READ_CHARS, fin);
-    position = read_buffer + 3; /*skip the "cpu" */
-    sscanf(position , "%d", &curU);
+	if (!g_file_get_contents (CPUFILE, &contents, &lenght, &error)) {
+		fprintf (stderr, "ERR: can't read file %s: %s\n", CPUFILE, error->message);
+		g_error_free (error);
+		return 0;
+	}
+	
+	splits = g_strsplit_set (contents, " ",  -1);
 
-    snprintf(digits, MAX_DIGITS_CHARS, "%d", curU);
-    position = strstr(position, digits) + strlen(digits);
-    sscanf(position, "%d", &curN);
+	sscanf(splits[2] , "%d", &curU);
+	sscanf(splits[3], "%d", &curN);
+	sscanf(splits[4], "%d", &curIO);
+	sscanf(splits[5], "%d", &curI);
+	
+	g_strfreev (splits);
+	g_free (contents);
+    
+	idle = (curI - lastI);
+	if (idle == 0) load = 100;
+	else load = 100-idle;
+	if (load>100) load = 0;
+	deltaU = curU - lastU;
+	deltaN = curN - lastN;
+	deltaIO = curIO - lastIO;
+	deltaI = curI - lastI;
+	lastU = curU;
+	lastN = curN;
+	lastIO = curIO;
+	lastI = curI;
 
-    snprintf(digits, MAX_DIGITS_CHARS, "%d", curN);
-    position = strstr(position, digits) + strlen(digits);
-    sscanf(position, "%d", &curIO);
-
-    snprintf(digits, MAX_DIGITS_CHARS, "%d", curIO);
-    position = strstr(position, digits) + strlen(digits);
-    sscanf(position, "%d", &curI);
-    idle = (curI-lastI);
-    if (idle == 0) load = 100;
-    else load = 100-idle;
-    if (load>100) load = 0;
-    lastU = curU;
-    lastN = curN;
-    lastIO = curIO;
-    lastI = curI;
-    fclose(fin);
-
-    if (load > CPU_HIGH)
-        return 4;
-    else if (load > CPU_MID)
-        return 3;
-    else  if (load > CPU_LOW)
-        return 2;
-    else
-        return 1;
+	if (load > CPU_HIGH)
+		return 4;
+	else if (load > CPU_MID)
+		return 3;
+	else  if (load > CPU_LOW)
+		return 2;
+	else
+		return 1;
 }
 
 
@@ -769,6 +772,7 @@ la_load_pixmap(const gchar* location)
    if (error)
    {
        g_error("Loading %s failed with : %s", location, error->message);
+       g_error_free (error);
    }
    return pixbuf;
 }
